@@ -1,6 +1,6 @@
 EMAIL_BACKENDS = {
     'mailjet': {
-        'backend': 'django_email_multibackend.tests.FakeSmtpMailBackend',
+        'backend': 'django_email_multibackend.tests.FakeTransactionalMailBackend',
         'host': '',
         'port': '',
         'username': '',
@@ -8,7 +8,7 @@ EMAIL_BACKENDS = {
         'use_tls': '',
     },
     'mailchimp': {
-        'backend': 'django_email_multibackend.tests.FakeConsoleMailBackend',
+        'backend': 'django_email_multibackend.tests.FakeCampaignMailBackend',
         'host': '',
         'port': '',
         'username': '',
@@ -21,4 +21,10 @@ EMAIL_BACKENDS_WEIGHTS = (
     ('mailjet', 5), ('mailchimp', 3)
 )
 
+EMAIL_BACKENDS_CONDITIONS = {
+    'mailjet': [
+        ('django_email_multibackend.conditions.ExcludeMailByHeader', {'header': ('X-MAIL-TYPE', 'non-transactional')})
+    ]
+}
+
 SECRET_KEY = 'just_because_django_needs_this'
